package com.ruoyi.invest.domain.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.invest.domain.*;
import com.ruoyi.tool.domain.TUnifyFile;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.Date;
import java.util.List;

/**
 * 项目池对象 t_project_pool
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
@Data
public class TProjectPoolVo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键id */
    @ApiModelProperty("主键id")
    private String id;

    private String procInstId;

    /** 项目名称 */
    @Excel(name = "项目名称")
    private String projectName;

    /** 所属组别 */
    @Excel(name = "所属组别")
    private String projectGroup;

    /** 录入日期 */
    private Date recordDate;

    /** 项目编号 */
    @Excel(name = "项目编号")
    private String projectCode;

    /** 渠道 */
    @Excel(name = "渠道")
    private String channel;

    /** 初次接触日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "初次接触日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date contactDate;

    /** 立项通过日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "立项通过日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date projectDate;

    /** 投决通过日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "投决通过日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date decisionDate;

    /** 项目所属行业 */
    @Excel(name = "项目所属行业")
    private String industry;

    /** 项目所属公司 */
    @Excel(name = "项目所属公司")
    private String company;

    /** 项目情况描述 */
    private String description;

    /** 项目联系人 */
    @Excel(name = "项目联系人")
    private String projectContacts;

    /** 投资负责人 */
    @Excel(name = "投资负责人")
    private String investHead;

    /** 历次融资 */
    @Excel(name = "历次融资")
    private String previousFinancing;

    /** 项目融资阶段 */
    @Excel(name = "项目融资阶段")
    private String financingStage;

    /** 融资条件 */
    private String financingCondition;

    /** 预期融资金额（万元） */
    @Excel(name = "预期融资金额")
    private String financingMoney;

    /** 预期融资时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
//    @Excel(name = "预期融资时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date financingDate;

    /** 投资亮点 */
    private String investSparkle;

    /** 投前估值（万元） */
    @Excel(name = "投前估值")
    private String investValuation;

    /** 预计投资金额（万元） */
    @Excel(name = "预计投资金额")
    private String investMoney;

    /** 投资类型 */
    @Excel(name = "投资类型")
    private String investType;

    /** 投资策略 */
    @Excel(name = "投资策略")
    private String investPloy;

    /** 投资价值 */
    @Excel(name = "投资价值")
    private String investWorth;

    /** 股权架构 */
    private String shareholding;

    /** 项目阶段 */
    @Excel(name = "项目阶段")
    private String projectStage;

    /** 项目状态 */
    @Excel(name = "项目状态")
    private String projectState;

    /** 备注 */
    private String mark;

    /** 状态 */
    private String delFlag;

    /** 公司信息 */
    @ApiModelProperty("公司信息")
    private TProjectCompany tProjectCompany;

    /** 联系人信息 */
    @ApiModelProperty("联系人信息")
    private TProjectContacts tProjectContacts;

    /** 渠道信息 */
    @ApiModelProperty("渠道信息")
    private TProjectChannel tProjectChannel;

    /** 评审信息 */
    @ApiModelProperty("评审信息")
    private TProjectReview tProjectReview;

    /** 会议信息 */
    @ApiModelProperty("会议信息")
    private TProjectMeeting tProjectMeeting;

    /** 打分记录 */
    @ApiModelProperty("打分记录")
    private TProjectScoring tProjectScoring;

    /** 尽调信息 */
    @ApiModelProperty("尽调信息")
    private TProjectInvestigate tProjectInvestigate;

    /** 尽调人员信息 */
    @ApiModelProperty("尽调人员信息")
    private TProjectInvestigatePerson tProjectInvestigatePerson;

    /**
     * 附件信息
     */
    @ApiModelProperty("附件信息")
    private List<TUnifyFile> listFile;

    /**
     * bp附件信息
     */
    @ApiModelProperty("bp附件信息")
    private List<TUnifyFile> bpFile;

    /**
     * 其他附件信息
     */
    @ApiModelProperty("其他附件信息")
    private List<TUnifyFile> otherFile;

    /**
     * 阶段名称
     */
    @ApiModelProperty("阶段名称")
    private String stageName;

    /**
     * 状态名称
     */
    @ApiModelProperty("状态名称")
    private String stateName;

    /**
     * 立项申请状态
     */
    private String approvalFlag;

    /**
     * 尽调申请状态
     */
    private String investigateFlag;

    /**
     * 投决申请状态
     */
    private String decisionFlag;
    /**
     * 终止申请状态
     */
    private String terminationFlag;
    /**
     * 流程状态
     */
    private Integer status;
    /**
     * 项目状态（0正常、1终止、2观望）
     */
    @ApiModelProperty("项目机会状态")
    private String projectStatus;

    //流程信息
    @ApiModelProperty("流程实例ID")
    private String procInsId;
    @ApiModelProperty("流程ID")
    private String procDefId;
    //private String processDefName;
    @ApiModelProperty("流程部署编号")
    private String deployId;
    //流程任务信息
    @ApiModelProperty("任务编号")
    private String taskId;
    @ApiModelProperty("任务执行编号")
    private String executionId;// 运行id
    @ApiModelProperty("任务名称")
    private String taskName;
    @ApiModelProperty("任务Key")
    private String taskDefKey;
    private String taskCreateTiem; // 当前节点创建时间
    //private String taskUserId; // 当前处理人
    //private String status; // 流程状态
    @ApiModelProperty("任务执行人Id")
    private String assignee; // 该值未空表示 可签收，不未空表示 可处理
    @ApiModelProperty("任务执行人名称")
    private String assigneeName;
    //流程发起人信息
    @ApiModelProperty("流程发起人Id")
    private String startUserId;
    @ApiModelProperty("流程发起人名称")
    private String startUserName;
    @ApiModelProperty("流程发起人部门名称")
    private String startDeptName;

    public void setId(String id)
    {
        this.id = id;
    }

    public String getId()
    {
        return id;
    }
    public void setProjectName(String projectName)
    {
        this.projectName = projectName;
    }

    public String getProcInstId() {
        return procInstId;
    }

    public void setProcInstId(String procInstId) {
        this.procInstId = procInstId;
    }

    public String getProjectName()
    {
        return projectName;
    }
    public void setProjectGroup(String projectGroup)
    {
        this.projectGroup = projectGroup;
    }

    public String getProjectGroup()
    {
        return projectGroup;
    }
    public void setRecordDate(Date recordDate)
    {
        this.recordDate = recordDate;
    }

    public Date getRecordDate()
    {
        return recordDate;
    }
    public void setProjectCode(String projectCode)
    {
        this.projectCode = projectCode;
    }

    public String getProjectCode()
    {
        return projectCode;
    }
    public void setChannel(String channel)
    {
        this.channel = channel;
    }

    public String getChannel()
    {
        return channel;
    }
    public void setContactDate(Date contactDate)
    {
        this.contactDate = contactDate;
    }

    public Date getContactDate()
    {
        return contactDate;
    }
    public void setProjectDate(Date projectDate)
    {
        this.projectDate = projectDate;
    }

    public Date getProjectDate()
    {
        return projectDate;
    }
    public void setDecisionDate(Date decisionDate)
    {
        this.decisionDate = decisionDate;
    }

    public Date getDecisionDate()
    {
        return decisionDate;
    }
    public void setIndustry(String industry)
    {
        this.industry = industry;
    }

    public String getIndustry()
    {
        return industry;
    }
    public void setCompany(String company)
    {
        this.company = company;
    }

    public String getCompany()
    {
        return company;
    }
    public void setDescription(String description)
    {
        this.description = description;
    }

    public String getDescription()
    {
        return description;
    }
    public void setProjectContacts(String projectContacts)
    {
        this.projectContacts = projectContacts;
    }

    public String getProjectContacts()
    {
        return projectContacts;
    }
    public void setInvestHead(String investHead)
    {
        this.investHead = investHead;
    }

    public String getInvestHead()
    {
        return investHead;
    }
    public void setPreviousFinancing(String previousFinancing)
    {
        this.previousFinancing = previousFinancing;
    }

    public String getPreviousFinancing()
    {
        return previousFinancing;
    }
    public void setFinancingStage(String financingStage)
    {
        this.financingStage = financingStage;
    }

    public String getFinancingStage()
    {
        return financingStage;
    }
    public void setFinancingCondition(String financingCondition)
    {
        this.financingCondition = financingCondition;
    }

    public String getFinancingCondition()
    {
        return financingCondition;
    }
    public void setFinancingMoney(String financingMoney)
    {
        this.financingMoney = financingMoney;
    }

    public String getFinancingMoney()
    {
        return financingMoney;
    }
    public void setFinancingDate(Date financingDate)
    {
        this.financingDate = financingDate;
    }

    public Date getFinancingDate()
    {
        return financingDate;
    }
    public void setInvestSparkle(String investSparkle)
    {
        this.investSparkle = investSparkle;
    }

    public String getInvestSparkle()
    {
        return investSparkle;
    }
    public void setInvestValuation(String investValuation)
    {
        this.investValuation = investValuation;
    }

    public String getInvestValuation()
    {
        return investValuation;
    }
    public void setInvestMoney(String investMoney)
    {
        this.investMoney = investMoney;
    }

    public String getInvestMoney()
    {
        return investMoney;
    }
    public void setInvestType(String investType)
    {
        this.investType = investType;
    }

    public String getInvestType()
    {
        return investType;
    }
    public void setInvestPloy(String investPloy)
    {
        this.investPloy = investPloy;
    }

    public String getInvestPloy()
    {
        return investPloy;
    }
    public void setInvestWorth(String investWorth)
    {
        this.investWorth = investWorth;
    }

    public String getInvestWorth()
    {
        return investWorth;
    }
    public void setShareholding(String shareholding)
    {
        this.shareholding = shareholding;
    }

    public String getShareholding()
    {
        return shareholding;
    }
    public void setProjectStage(String projectStage)
    {
        this.projectStage = projectStage;
    }

    public String getProjectStage()
    {
        return projectStage;
    }
    public void setProjectState(String projectState)
    {
        this.projectState = projectState;
    }

    public String getProjectState()
    {
        return projectState;
    }
    public void setMark(String mark)
    {
        this.mark = mark;
    }

    public String getMark()
    {
        return mark;
    }
    public void setDelFlag(String delFlag)
    {
        this.delFlag = delFlag;
    }

    public String getDelFlag()
    {
        return delFlag;
    }

    public TProjectCompany gettProjectCompany() {
        return tProjectCompany;
    }

    public void settProjectCompany(TProjectCompany tProjectCompany) {
        this.tProjectCompany = tProjectCompany;
    }

    public TProjectContacts gettProjectContacts() {
        return tProjectContacts;
    }

    public void settProjectContacts(TProjectContacts tProjectContacts) {
        this.tProjectContacts = tProjectContacts;
    }

    public List<TUnifyFile> getListFile() {
        return listFile;
    }

    public void setListFile(List<TUnifyFile> listFile) {
        this.listFile = listFile;
    }

    public String getStageName() {
        return stageName;
    }

    public void setStageName(String stageName) {
        this.stageName = stageName;
    }

    public TProjectChannel gettProjectChannel() {
        return tProjectChannel;
    }

    public void settProjectChannel(TProjectChannel tProjectChannel) {
        this.tProjectChannel = tProjectChannel;
    }

    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }

    public List<TUnifyFile> getBpFile() {
        return bpFile;
    }

    public void setBpFile(List<TUnifyFile> bpFile) {
        this.bpFile = bpFile;
    }

    public List<TUnifyFile> getOtherFile() {
        return otherFile;
    }

    public void setOtherFile(List<TUnifyFile> otherFile) {
        this.otherFile = otherFile;
    }

    public TProjectReview gettProjectReview() {
        return tProjectReview;
    }

    public void settProjectReview(TProjectReview tProjectReview) {
        this.tProjectReview = tProjectReview;
    }

    public TProjectInvestigate gettProjectInvestigate() {
        return tProjectInvestigate;
    }

    public void settProjectInvestigate(TProjectInvestigate tProjectInvestigate) {
        this.tProjectInvestigate = tProjectInvestigate;
    }

    public String getApprovalFlag() {
        return approvalFlag;
    }

    public void setApprovalFlag(String approvalFlag) {
        this.approvalFlag = approvalFlag;
    }

    public String getInvestigateFlag() {
        return investigateFlag;
    }

    public void setInvestigateFlag(String investigateFlag) {
        this.investigateFlag = investigateFlag;
    }

    public String getDecisionFlag() {
        return decisionFlag;
    }

    public void setDecisionFlag(String decisionFlag) {
        this.decisionFlag = decisionFlag;
    }

    public TProjectInvestigatePerson gettProjectInvestigatePerson() {
        return tProjectInvestigatePerson;
    }

    public void settProjectInvestigatePerson(TProjectInvestigatePerson tProjectInvestigatePerson) {
        this.tProjectInvestigatePerson = tProjectInvestigatePerson;
    }

    public TProjectMeeting gettProjectMeeting() {
        return tProjectMeeting;
    }

    public void settProjectMeeting(TProjectMeeting tProjectMeeting) {
        this.tProjectMeeting = tProjectMeeting;
    }

    public TProjectScoring gettProjectScoring() {
        return tProjectScoring;
    }

    public void settProjectScoring(TProjectScoring tProjectScoring) {
        this.tProjectScoring = tProjectScoring;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("projectName", getProjectName())
            .append("projectGroup", getProjectGroup())
            .append("recordDate", getRecordDate())
            .append("projectCode", getProjectCode())
            .append("channel", getChannel())
            .append("contactDate", getContactDate())
            .append("projectDate", getProjectDate())
            .append("decisionDate", getDecisionDate())
            .append("industry", getIndustry())
            .append("company", getCompany())
            .append("description", getDescription())
            .append("projectContacts", getProjectContacts())
            .append("investHead", getInvestHead())
            .append("previousFinancing", getPreviousFinancing())
            .append("financingStage", getFinancingStage())
            .append("financingCondition", getFinancingCondition())
            .append("financingMoney", getFinancingMoney())
            .append("financingDate", getFinancingDate())
            .append("investSparkle", getInvestSparkle())
            .append("investValuation", getInvestValuation())
            .append("investMoney", getInvestMoney())
            .append("investType", getInvestType())
            .append("investPloy", getInvestPloy())
            .append("investWorth", getInvestWorth())
            .append("shareholding", getShareholding())
            .append("projectStage", getProjectStage())
            .append("projectState", getProjectState())
            .append("mark", getMark())
            .append("delFlag", getDelFlag())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .toString();
    }
}
